@@ -29,6 +29,7 @@ MAX_CHANNELS = 512
 MAX_FPS = 10**4
 MIN_INTENSITY = 0
 MAX_INTENSITY = 255
+MAX_PRIORITY = 255
 MAX_UNIVERSE = 63999
 
 
@@ -132,6 +133,13 @@ def parse_args(args=None):
         type=range_limited_int_type(lower=MIN_INTENSITY, upper=MAX_INTENSITY),
         help=f"DMX channels minimum output intensity (range: {MIN_INTENSITY}-{MAX_INTENSITY}, default: 0)",  # noqa: E501 # pylint: disable=line-too-long
     )
+    argparser.add_argument(
+        "-p",
+        "--priority",
+        default=100,
+        type=range_limited_int_type(upper=MAX_PRIORITY),
+        help=f"DMX source priority (range: 1-{MAX_PRIORITY}, default: %(default)s)",
+    )
     argparser.add_argument(
         "-f",
         "--frequency",
@@ -229,11 +237,13 @@ def main(args=None):
         )
 
         dispatcher = SACNDispatcher(
+            source_name=f"{PACKAGE_NAME} {__version__}",
             channels=args.channels,
             fps=args.fps,
             universes=args.universes,
             src_ip_address=args.IP_ADDRESS,
             dst_ip_address=args.dst,
+            priority=args.priority,
         )
 
         if not args.quiet and not args.purge:
